==> hs-json-0.9.1.tgz: lib/ghc/json-0.9.1/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-json-0.9.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: json
version: 0.9.1
id: json-0.9.1-LsxwzMHf4pS7O5VCo6vFnl
key: json-0.9.1-LsxwzMHf4pS7O5VCo6vFnl
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Parsec Text.JSON.Pretty
    Text.JSON.ReadP Text.JSON.String Text.JSON.Types
abi: 90ee24ed1afe0081060cad053d2e2365
trusted: False
import-dirs: /usr/local/lib/ghc/json-0.9.1
library-dirs: /usr/local/lib/ghc/json-0.9.1
              /usr/local/lib/i386-openbsd-ghc-8.2.2
data-dir: /usr/local/share/hs-json-0.9.1
hs-libraries: HSjson-0.9.1-LsxwzMHf4pS7O5VCo6vFnl
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH parsec-3.1.9-444fzLM2idQ5vByZuGIOJ
    pretty-1.1.3.3 syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ
abi-depends: array-0.5.2.0=c3a92ef97c0191e4bc82f0a7399f51b4
             base-4.10.1.0=3c10740f6cf9df7b9dca6d01ba411ea7
             bytestring-0.10.8.2=3f834c69e2158c4ad5032b0346c29480
             containers-0.5.10.2=a2c92baf4a812b005ca4fa7f0772cd30
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=ff60e0c200c475a016137ee0a9ed1f03
             parsec-3.1.9-444fzLM2idQ5vByZuGIOJ=7e464826ac815eee6510ec2a536780a9
             pretty-1.1.3.3=7e4ff47e6f9a790083a87f97e74bf9b6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=b1a0749241d60cd9cb23238118c20171
             text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ=5ca4db1764ff5f5e0d9e99e51b5e0b7d
haddock-interfaces: /usr/local/share/doc/hs-json-0.9.1/html/json.haddock
haddock-html: /usr/local/share/doc/hs-json-0.9.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-json-0.9.2.tgz: lib/ghc/json-0.9.2/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-json-0.9.2/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: json
version: 0.9.2
id: json-0.9.2-7rB8qNGKE8tQN0WTAH0G5
key: json-0.9.2-7rB8qNGKE8tQN0WTAH0G5
license: BSD3
copyright: (c) 2007-2009 Galois Inc.
maintainer: Iavor S. Diatchki (iavor.diatchki@gmail.com)
synopsis: Support for serialising Haskell to and from JSON
description:
    JSON (JavaScript Object Notation) is a lightweight data-interchange
    format. It is easy for humans to read and write. It is easy for
    machines to parse and generate.  It is based on a subset of the
    JavaScript Programming Language, Standard ECMA-262 3rd Edition -
    December 1999.
    .
    This library provides a parser and pretty printer for converting
    between Haskell values and JSON.
category: Web
author: Galois Inc.
exposed: True
indefinite: False
exposed-modules:
    Text.JSON Text.JSON.Generic Text.JSON.Parsec Text.JSON.Pretty
    Text.JSON.ReadP Text.JSON.String Text.JSON.Types
abi: c5a329913f2be24155842e8fa1d5a5a0
trusted: False
import-dirs: /usr/local/lib/ghc/json-0.9.2
library-dirs: /usr/local/lib/ghc/json-0.9.2
              /usr/local/lib/i386-openbsd-ghc-8.2.2
data-dir: /usr/local/share/hs-json-0.9.2
hs-libraries: HSjson-0.9.2-7rB8qNGKE8tQN0WTAH0G5
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH parsec-3.1.9-444fzLM2idQ5vByZuGIOJ
    pretty-1.1.3.3 syb-0.7-3Lq8MQxmYP07qktjI1jxu0
    text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ
abi-depends: array-0.5.2.0=697bb2e271f4abe8dd4fe94a4528e7cb
             base-4.10.1.0=3c10740f6cf9df7b9dca6d01ba411ea7
             bytestring-0.10.8.2=2a4bbfd60b4f148922e8caf44d9009f9
             containers-0.5.10.2=2ff387bb382d9f510ffcf8f3ed2013c5
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=ff60e0c200c475a016137ee0a9ed1f03
             parsec-3.1.9-444fzLM2idQ5vByZuGIOJ=597887a48283a4fccf50985e5cc89cb8
             pretty-1.1.3.3=7e4ff47e6f9a790083a87f97e74bf9b6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=b1a0749241d60cd9cb23238118c20171
             text-1.2.1.3-5I6D6Lq0QEU97eY5wqs6DJ=77e10b579708f506156fd8ed84f18afc
haddock-interfaces: /usr/local/share/doc/hs-json-0.9.2/html/json.haddock
haddock-html: /usr/local/share/doc/hs-json-0.9.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
